[zorg] r177902 - Bump up the Clang LTO Builder timeout to 120 minutes.

Michael Gottesman mgottesman at apple.com
Mon Mar 25 13:23:45 PDT 2013


Author: mgottesman
Date: Mon Mar 25 15:23:45 2013
New Revision: 177902

URL: http://llvm.org/viewvc/llvm-project?rev=177902&view=rev
Log:
Bump up the Clang LTO Builder timeout to 120 minutes.

Modified:
    zorg/trunk/zorg/buildbot/builders/ClangBuilder.py

Modified: zorg/trunk/zorg/buildbot/builders/ClangBuilder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/ClangBuilder.py?rev=177902&r1=177901&r2=177902&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/ClangBuilder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/ClangBuilder.py Mon Mar 25 15:23:45 2013
@@ -756,7 +756,7 @@ def phasedClang(config_options, is_boots
     timeout = 20*60 # Normal timeout is 20 minutes.
     if use_lto:
         make_command.append(WithProperties('DYLD_LIBRARY_PATH=%(liblto_path)s'))
-        timeout = 90*60 # LTO timeout is 90 minutes.
+        timeout = 120*60 # LTO timeout is 120 minutes.
     
     f.addStep(buildbot.steps.shell.ShellCommand(
               name='make', command=make_command,





More information about the llvm-commits mailing list